@@ -33,7 +33,7 @@ def dataset_classifier_XXXXX(nrows=500, **kw):
 
 
 ####################################################################################################
-def split(df, coly=None):
+def pd_train_test_split(df, coly=None):
     X,y = df.drop(coly), df[[coly]]
     X_train_full, X_test, y_train_full, y_test = train_test_split(X, y, test_size=0.05, random_state=2021)
     X_train, X_valid, y_train, y_valid         = train_test_split(X_train_full, y_train_full, random_state=2021)
@@ -41,6 +41,16 @@ def split(df, coly=None):
 
 
 
+def pd_train_test_split2(df, coly):
+    log2(df.dtypes)
+    X,y = df.drop(coly,  axis=1), df[coly]
+    log2('y', np.sum(y[y==1]) , X.head(3))
+    X_train_full, X_test, y_train_full, y_test = train_test_split(X, y, test_size=0.05, random_state=2021)
+    X_train, X_valid, y_train, y_valid         = train_test_split(X_train_full, y_train_full, random_state=2021)
+    num_classes                                = len(set(y_train_full.values.ravel()))
+    return X,y, X_train, X_valid, y_train, y_valid, X_test,  y_test, num_classes
+
+
 
 ####################################################################################################
 ####################################################################################################
@@ -55,39 +65,34 @@ def dataset_classifier_pmlb(name='', return_X_y=False):
 
 
 def test_dataset_classifier_covtype(nrows=500):
+    log("start")
+
     import wget
     # Dense features
     colnum = ["Elevation", "Aspect", "Slope", "Horizontal_Distance_To_Hydrology",]
 
     # Sparse features
     colcat = ["Wilderness_Area1",  "Wilderness_Area2", "Wilderness_Area3",
-        "Wilderness_Area4",  "Soil_Type1",  "Soil_Type2",  "Soil_Type3",
-        "Soil_Type4",  "Soil_Type5",  "Soil_Type6",  "Soil_Type7",  "Soil_Type8",  "Soil_Type9",  ]
+              "Wilderness_Area4",  "Soil_Type1",  "Soil_Type2",  "Soil_Type3",
+              "Soil_Type4",  "Soil_Type5",  "Soil_Type6",  "Soil_Type7",  "Soil_Type8",  "Soil_Type9",  ]
 
     # Target column
-    coly        = ["Covertype"]
+    coly   = ["Covertype"]
 
-    log("start")
-
-    root     = os.path.join(os.getcwd() ,"ztmp")
-    BASE_DIR = Path.home().joinpath( root, 'data/input/covtype/')
-    datafile = BASE_DIR.joinpath('covtype.data.gz')
-    datafile.parent.mkdir(parents=True, exist_ok=True)
-    url = "https://archive.ics.uci.edu/ml/machine-learning-databases/covtype/covtype.data.gz"
-
-    # Download the dataset in case it's missing
-    if not datafile.exists():
-        wget.download(url, datafile.as_posix())
+    datafile = os.getcwd() + "/ztmp/covtype/covtype.data.gz"
+    os_makedirs(os.path.dirname(datafile))
+    url      = "https://archive.ics.uci.edu/ml/machine-learning-databases/covtype/covtype.data.gz"
+    if not Path(datafile).exists():
+        wget.download(url, datafile)
 
     # Read nrows of only the given columns
     feature_columns = colnum + colcat + coly
-    df = pd.read_csv(datafile, header=None, names=feature_columns, nrows=nrows)
+    df   = pd.read_csv(datafile, header=None, names=feature_columns, nrows=nrows)
     pars = { 'colnum': colnum, 'colcat': colcat, "coly": coly }
 
     return df, pars
 
 
-
 def test_dataset_regression_fake(nrows=500, n_features=17):
     from sklearn import datasets as sklearn_datasets
     coly   = 'y'
